import "CoreLibs/graphics"
import "CoreLibs/object"
import "pixie"

local gfx <const> = playdate.graphics

local defaultFont = gfx.font.new("fonts/Mini Mono")

class("TextBox").extends(gfx.sprite)

-- text - the initial text to display
-- w, h - width and height of the text box
-- x, y - initial position for the text box (center)
-- vert - vertical offset for the text (from the top of the box)
-- align - text alignment
-- font - font (defaults to Mini Mono)
function TextBox:init(text, w, h, x, y, vert, align, font)
   TextBox.super.init(self)

   self.text = text
   self:setSize(w, h)
   self:moveTo(x, y)
   self.vert = vert or 0
   self.align = align or kTextAlignment.left
   self.font = font or defaultFont

   self:setZIndex(999)
   self:drawStatic()
end

function TextBox:setText(text)
   self.text = text
   self:drawStatic()
end

function TextBox:drawStatic()
   local img = gfx.image.new(self:getSize())
   local x = 0
   local y = 0
   local w = self.width
   local h = self.height
   gfx.pushContext(img)
      gfx.setColor(gfx.kColorWhite)
      gfx.fillRect(x, y, w, h)
      gfx.setColor(gfx.kColorBlack)
      gfx.drawRoundRect(x, y, w, h, 2)

      gfx.setFont(self.font)
      gfx.drawTextInRect(
         self.text,
         x, y+self.vert, w, h, nil, nil, self.align
      )
   gfx.popContext()
   self:setImage(img)
end

-- draw the textbox. This is in a sub-function so we can change the context
-- depending on static-ness
function TextBox:subDraw(x, y, w, h)
   gfx.setColor(gfx.kColorWhite)
   gfx.fillRect(x, y, w, h)
   gfx.setColor(gfx.kColorBlack)
   gfx.drawRoundRect(x, y, w, h, 2)

   gfx.setFont(self.font)
   gfx.drawTextInRect(
      self.text,
      x, y+self.vert, w, h, nil, nil, self.align
   )
end
